@@ -80,8 +80,8 @@ pub mod inline_response_200_6;
 pub use self::inline_response_200_6::InlineResponse2006;
 pub mod inline_response_200_7;
 pub use self::inline_response_200_7::InlineResponse2007;
-pub mod inline_response_401;
-pub use self::inline_response_401::InlineResponse401;
+pub mod inline_response_403;
+pub use self::inline_response_403::InlineResponse403;
 pub mod instance;
 pub use self::instance::Instance;
 pub mod instance_platforms;
@@ -98,6 +98,10 @@ pub mod notification;
 pub use self::notification::Notification;
 pub mod notification_type;
 pub use self::notification_type::NotificationType;
+pub mod past_display_name;
+pub use self::past_display_name::PastDisplayName;
+pub mod permission;
+pub use self::permission::Permission;
 pub mod platform;
 pub use self::platform::Platform;
 pub mod player_moderation;
